@@ -1,3 +1,7 @@
+#
+# Validate every links within html pages and csses.
+#
+
 use strict;
 use warnings;
 use utf8;
@@ -5,11 +9,13 @@ use WWW::Crawler::Mojo;
 use 5.10.0;
 use Mojo::URL;
 
+@ARGV || die 'Starting URL must given';
+my @start = map {Mojo::URL->new($_)} @ARGV;
+my @hosts = map {$_->host} @start;
+
 my $bot = WWW::Crawler::Mojo->new;
 my %count;
 
-my $start = Mojo::URL->new(pop @ARGV || die 'Starting URL must given');
-
 $bot->on(start => sub {
     shift->say_start;
 });
@@ -31,40 +37,39 @@ $bot->on(res => sub {
     
     $count{$res->code}++;
     
-    if ($res->code =~ qr{[54]..}) {
+    if ($res->code =~ qr{[245]..}) {
         my $msg = $res->code. ' occured!';
-        report_stdout($msg, $job->url, $job->referrer->url);
+        report_stdout(
+                $msg, $job->url, $job->referrer ? $job->referrer->url : '-');
     }
     
     $count{QUEUE} = $bot->queue->length;
     my @props = map { join(':', $_, $count{$_}) } (sort keys %count);
     print join(' / ', @props), ' ' x 30, "\r";
     
-    $scrape->(sub {
-        my ($bot, $enqueue, $job2, $context) = @_;
-        
-        if (security_warning($job2, $context)) {
+    return unless grep {$_ eq $job->url->host} @hosts;
+    
+    for my $job2 ($scrape->()) {
+        if (security_warning($job2, $job2->context)) {
             $count{'WARNING'}++;
             my $msg = 'WARNING : Cross-scheme resource found';
             report_stdout($msg, $job2->url, $job->url);
         }
-        
-        #$enqueue->() if ($job->url->host eq $start->host);
-        $enqueue->() ;
-    });
+        $bot->enqueue($job2);
+    }
 });
 
 $bot->shuffle(5);
 $bot->max_conn_per_host(2);
 $bot->max_conn(5);
-$bot->enqueue($start);
+$bot->enqueue(@start);
 $bot->crawl;
 
 sub report_stdout {
     my ($msg, $url, $url_referrer) = @_;
     state $index = 1;
     say sprintf(
-        '%s: %s at %s referred by %s',
+        '%s: %s at %s <= %s',
         $index++,
         $msg,
         $url,
